# Koliba

This is a Python port of the [koliba library](https://github.com/Pantarheon/libkoliba).
Or will be when it is completed. :)

You need to have it installed on your system. The easiest way is to download it
by git from the above-mentioned link.
